@@ -252,6 +252,8 @@ class Puppet::Type
             param.required_features = options[:required_features]
         end
 
+        param.isnamevar if options[:namevar]
+
         # These might be enabled later.
 #        define_method(name) do
 #            @parameters[name].value
@@ -426,8 +428,7 @@ class Puppet::Type
             if defined? @title and @title
                 hash[namevar] = @title
             else
-                raise Puppet::Error,
-                    "Was not passed a namevar or title"
+                raise Puppet::Error, "Was not passed a namevar or title"
             end
         end
 
@@ -686,4 +687,3 @@ class Puppet::Type
     end
 end
 
-# $Id: attributes.rb 2676 2007-07-10 23:24:34Z luke $
