@@ -16,28 +16,26 @@ Puppet::Type.type(:package).provide :freebsd, :parent => :openbsd do
     end
 
     def install
-        should = @model.should(:ensure)
+        should = @resource.should(:ensure)
 
-        if @model[:source]
+        if @resource[:source]
             return super
         end
 
-        pkgadd "-r", @model[:name]
+        pkgadd "-r", @resource[:name]
     end
 
     def query
-        self.class.list
-
-        if @model.is(:ensure)
-            return :listed
-        else
-            return nil
+        self.class.instances.each do |provider|
+            if provider.name == @resource.name
+                return provider.properties
+            end
         end
+        return nil
     end
 
     def uninstall
-        pkgdelete "%s-%s" % [@model[:name], @model.should(:ensure)]
+        pkgdelete "%s-%s" % [@resource[:name], @resource.should(:ensure)]
     end
 end
 
-# $Id: freebsd.rb 1979 2006-12-28 08:06:46Z luke $
