@@ -6,21 +6,17 @@ Puppet::Type.type(:service).provide :redhat, :parent => :init do
 
     commands :chkconfig => "/sbin/chkconfig"
 
-    defaultfor :operatingsystem => [:redhat, :fedora, :suse]
+    defaultfor :operatingsystem => [:redhat, :fedora, :suse, :centos]
 
     def self.defpath
         superclass.defpath
     end
 
-    if self.suitable?
-        Puppet.type(:service).newpath(:redhat, defpath())
-    end
-
     # Remove the symlinks
     def disable
         begin
-            output = chkconfig(@model[:name], :off)
-            output += chkconfig("--del", @model[:name])
+            output = chkconfig(@resource[:name], :off)
+            output += chkconfig("--del", @resource[:name])
         rescue Puppet::ExecutionFailure
             raise Puppet::Error, "Could not disable %s: %s" %
                 [self.name, output]
@@ -29,7 +25,7 @@ Puppet::Type.type(:service).provide :redhat, :parent => :init do
 
     def enabled?
         begin
-            output = chkconfig(@model[:name])
+            output = chkconfig(@resource[:name])
         rescue Puppet::ExecutionFailure
             return :false
         end
@@ -47,8 +43,8 @@ Puppet::Type.type(:service).provide :redhat, :parent => :init do
     # in the init scripts.
     def enable
         begin
-            output = chkconfig("--add", @model[:name])
-            output += chkconfig(@model[:name], :on)
+            output = chkconfig("--add", @resource[:name])
+            output += chkconfig(@resource[:name], :on)
         rescue Puppet::ExecutionFailure => detail
             raise Puppet::Error, "Could not enable %s: %s" %
                 [self.name, detail]
@@ -56,4 +52,3 @@ Puppet::Type.type(:service).provide :redhat, :parent => :init do
     end
 end
 
-# $Id: redhat.rb 1979 2006-12-28 08:06:46Z luke $
