@@ -1,9 +1,10 @@
 #!/usr/bin/env ruby
 
-$:.unshift("../lib") if __FILE__ =~ /\.rb$/
+require File.dirname(__FILE__) + '/../lib/puppettest'
 
 require 'puppettest'
 require 'puppet/sslcertificates/support'
+require 'mocha'
 
 class TestCertSupport < Test::Unit::TestCase
     include PuppetTest
@@ -15,6 +16,7 @@ class TestCertSupport < Test::Unit::TestCase
 
     def setup
         super
+        Puppet::Util::SUIDManager.stubs(:asuser).yields
         @user = CertUser.new
         @ca = Puppet::SSLCertificates::CA.new
         @client = Puppet::Network::Client.ca.new(:CA => @ca)
@@ -78,4 +80,3 @@ class TestCertSupport < Test::Unit::TestCase
     end
 end
 
-# $Id: support.rb 2259 2007-03-06 19:03:05Z luke $
