@@ -1,11 +1,17 @@
 #!/usr/bin/env ruby
 
-$:.unshift("../lib").unshift("../../lib") if __FILE__ =~ /\.rb$/
+require File.dirname(__FILE__) + '/../lib/puppettest'
 
 require 'puppettest'
+require 'mocha'
 
 class TestPuppetCA < Test::Unit::TestCase
     include PuppetTest::ExeTest
+
+    def setup
+      super
+      Puppet::Util::SUIDManager.stubs(:asuser).yields
+    end
     
     def gen_cert(ca, host)
         runca("-g #{host}")
@@ -107,4 +113,3 @@ class TestPuppetCA < Test::Unit::TestCase
     end
 end
 
-# $Id: puppetca.rb 2259 2007-03-06 19:03:05Z luke $
