@@ -13,10 +13,17 @@ module PuppetTest::ExeTest
         File.join(basedir, "bin")
     end
 
+    def sbindir
+        File.join(basedir, "sbin")
+    end
+
     def setbindir
         unless ENV["PATH"].split(":").include?(bindir)
             ENV["PATH"] = [bindir, ENV["PATH"]].join(":")
         end
+        unless ENV["PATH"].split(":").include?(sbindir)
+            ENV["PATH"] = [sbindir, ENV["PATH"]].join(":")
+        end
     end
 
     def setlibdir
@@ -47,6 +54,7 @@ module PuppetTest::ExeTest
         args += " --confdir %s" % Puppet[:confdir]
         args += " --rundir %s" % File.join(Puppet[:vardir], "run")
         args += " --vardir %s" % Puppet[:vardir]
+        args += " --certdnsnames %s" % Puppet[:certdnsnames]
         args += " --masterport %s" % @@port
         args += " --user %s" % Puppet::Util::SUIDManager.uid
         args += " --group %s" % Puppet::Util::SUIDManager.gid
@@ -120,4 +128,3 @@ module PuppetTest::ExeTest
     end
 end
 
-# $Id$
