@@ -1,6 +1,6 @@
 #!/usr/bin/env ruby
 
-$:.unshift("../lib").unshift("../../lib") if __FILE__ =~ /\.rb$/
+require File.dirname(__FILE__) + '/../lib/puppettest'
 
 require 'puppet'
 require 'puppettest'
@@ -11,7 +11,7 @@ class TestPuppetModule < Test::Unit::TestCase
     include SignalObserver
     
     def mkfakeclient
-        Class.new(Puppet::Client) do
+        Class.new(Puppet::Network::Client) do
             def initialize
             end
 
@@ -83,6 +83,49 @@ class TestPuppetModule < Test::Unit::TestCase
 
         assert_equal(newpath, ENV["PATH"])
     end
+
+    def test_libdir
+        oldlibs = $:.dup
+        cleanup do
+            $:.each do |dir|
+                unless oldlibs.include?(dir)
+                    $:.delete(dir)
+                end
+            end
+        end
+        one = tempfile()
+        two = tempfile()
+        Dir.mkdir(one)
+        Dir.mkdir(two)
+
+        # Make sure setting the libdir gets the dir added to $:
+        assert_nothing_raised do
+            Puppet[:libdir] = one
+        end
+
+        assert($:.include?(one), "libdir was not added")
+
+        # Now change it, make sure it gets added and the old one gets
+        # removed
+        assert_nothing_raised do
+            Puppet[:libdir] = two
+        end
+
+        assert($:.include?(two), "libdir was not added")
+        assert(! $:.include?(one), "old libdir was not removed")
+    end
+
+    def test_name
+        # Make sure it defaults to $0 without the rb
+        should = $0.gsub(/.+#{File::SEPARATOR}/,'').sub(/\.rb$/, '')
+
+        assert_equal(should, Puppet[:name], "default name was not right")
+
+        assert_nothing_raised("Could not reset name") do
+            Puppet[:name] = "puppetca"
+        end
+
+        assert_equal("puppetca", Puppet[:name], "name reset did not take")
+    end
 end
 
-# $Id: puppet.rb 1793 2006-10-16 22:01:40Z luke $
