@@ -1,6 +1,6 @@
 #!/usr/bin/env ruby
 
-$:.unshift("../lib").unshift("../../lib") if __FILE__ =~ /\.rb$/
+require File.dirname(__FILE__) + '/../lib/puppettest'
 
 require 'puppet'
 require 'puppet/util/package'
@@ -24,4 +24,3 @@ class TestPuppetUtilPackage < Test::Unit::TestCase
     end
 end
 
-# $Id: package.rb 1793 2006-10-16 22:01:40Z luke $
